@@ -893,6 +893,47 @@ class RepositoryResponse:
         self.repository_url = repository_url
 
 
+class RepositoryProviderResponse:
+    def __init__(self, provider_id: str, name: str, details, status: str, account_id: str,
+                 repositories, errors: List[Error]):
+        self.provider_id = provider_id
+        self.errors = errors
+        self.account_id = account_id
+        self.name = name
+        self.type = type
+        self.details = details
+        self.status = status
+        self.repositories = repositories
+
+
+class AccountRepositoryResponse:
+    def __init__(self, repository_id: str, name: str, provider_id: str, allow_sharing: str, open_access: str,
+                 account_id: str, is_valid: bool, connection_details, repository_url: str, errors: List[Error]):
+        self.repository_url = repository_url
+        self.repository_id = repository_id
+        self.name = name
+        self.provider_id = provider_id
+        self.allow_sharing = allow_sharing
+        self.open_access = open_access
+        self.account_id = account_id
+        self.is_valid = is_valid
+        self.errors = errors
+        self.connection_details = connection_details
+
+
+class RepositoryRelationshipResponse:
+    def __init__(self, repo_relationship_id: str, space_id: str, deployment_type: str,
+                 account_id: str, branch: str, is_valid: bool, errors: List[Error]):
+
+        self.repo_relationship_id = repo_relationship_id
+        self.account_id = account_id
+        self.space_id = space_id
+        self.deployment_type = deployment_type
+        self.branch = branch
+        self.is_valid: bool = is_valid
+        self.errors = errors
+
+
 class SpaceAdmin:
     def __init__(self, first_name: str, last_name: str, account_role: str):
         self.last_name = last_name
@@ -990,21 +1031,6 @@ class VerifyCloudProviderResponse:
         self.resources_summary = resources_summary
 
 
-class AccountRepositoryResponse:
-    def __init__(self, name: str,
-                 allow_sharing: bool,
-                 open_access: bool,
-                 repository_url: str,
-                 repository_type: str,
-                 errors: []):
-        self.repository_name = name
-        self.allow_sharing = allow_sharing
-        self.open_access = open_access
-        self.repository_url = repository_url
-        self.repository_type = repository_type
-        self.errors = errors
-
-
 class AccountRepositoryDetailsBranchResponse:
     def __init__(self, name: str):
         self.name = name
